diff --git a/nixos/doc/manual/from_md/release-notes/rl-2305.section.xml b/nixos/doc/manual/from_md/release-notes/rl-2305.section.xml
index f57b3ca5b629..17fb70531054 100644
--- a/nixos/doc/manual/from_md/release-notes/rl-2305.section.xml
+++ b/nixos/doc/manual/from_md/release-notes/rl-2305.section.xml
@@ -238,6 +238,14 @@
the Nix store.
+
+
+ The services.fwupd module now allows
+ arbitrary daemon settings to be configured in a structured
+ manner
+ (services.fwupd.daemonSettings).
+
+
The unifi-poller package and corresponding
diff --git a/nixos/doc/manual/release-notes/rl-2305.section.md b/nixos/doc/manual/release-notes/rl-2305.section.md
index e64a80c6f713..b7f90ec01ef5 100644
--- a/nixos/doc/manual/release-notes/rl-2305.section.md
+++ b/nixos/doc/manual/release-notes/rl-2305.section.md
@@ -70,4 +70,6 @@ In addition to numerous new and upgraded packages, this release has the followin
- Resilio sync secret keys can now be provided using a secrets file at runtime, preventing these secrets from ending up in the Nix store.
+- The `services.fwupd` module now allows arbitrary daemon settings to be configured in a structured manner ([`services.fwupd.daemonSettings`](#opt-services.fwupd.daemonSettings)).
+
- The `unifi-poller` package and corresponding NixOS module have been renamed to `unpoller` to match upstream.
diff --git a/nixos/modules/services/hardware/fwupd.nix b/nixos/modules/services/hardware/fwupd.nix
index 98f837bd7824..8d7651f97c39 100644
--- a/nixos/modules/services/hardware/fwupd.nix
+++ b/nixos/modules/services/hardware/fwupd.nix
@@ -7,13 +7,16 @@ with lib;
let
cfg = config.services.fwupd;
+ format = pkgs.formats.ini {
+ listToValue = l: lib.concatStringsSep ";" (map (s: generators.mkValueStringDefault {} s) l);
+ mkKeyValue = generators.mkKeyValueDefault {} "=";
+ };
+
customEtc = {
"fwupd/daemon.conf" = {
- source = pkgs.writeText "daemon.conf" ''
- [fwupd]
- DisabledDevices=${lib.concatStringsSep ";" cfg.disabledDevices}
- DisabledPlugins=${lib.concatStringsSep ";" cfg.disabledPlugins}
- '';
+ source = format.generate "daemon.conf" {
+ fwupd = cfg.daemonSettings;
+ };
};
"fwupd/uefi_capsule.conf" = {
source = pkgs.writeText "uefi_capsule.conf" ''
@@ -67,24 +70,6 @@ in {
'';
};
- disabledDevices = mkOption {
- type = types.listOf types.str;
- default = [];
- example = [ "2082b5e0-7a64-478a-b1b2-e3404fab6dad" ];
- description = lib.mdDoc ''
- Allow disabling specific devices by their GUID
- '';
- };
-
- disabledPlugins = mkOption {
- type = types.listOf types.str;
- default = [];
- example = [ "udev" ];
- description = lib.mdDoc ''
- Allow disabling specific plugins
- '';
- };
-
extraTrustedKeys = mkOption {
type = types.listOf types.path;
default = [];
@@ -120,18 +105,49 @@ in {
Which fwupd package to use.
'';
};
+
+ daemonSettings = mkOption {
+ type = types.submodule {
+ freeformType = format.type.nestedTypes.elemType;
+ options = {
+ DisabledDevices = mkOption {
+ type = types.listOf types.str;
+ default = [];
+ example = [ "2082b5e0-7a64-478a-b1b2-e3404fab6dad" ];
+ description = lib.mdDoc ''
+ List of device GUIDs to be disabled.
+ '';
+ };
+
+ DisabledPlugins = mkOption {
+ type = types.listOf types.str;
+ default = [];
+ example = [ "udev" ];
+ description = lib.mdDoc ''
+ List of plugins to be disabled.
+ '';
+ };
+ };
+ };
+ default = {};
+ description = lib.mdDoc ''
+ Configurations for the fwupd daemon.
+ '';
+ };
};
};
imports = [
- (mkRenamedOptionModule [ "services" "fwupd" "blacklistDevices"] [ "services" "fwupd" "disabledDevices" ])
- (mkRenamedOptionModule [ "services" "fwupd" "blacklistPlugins"] [ "services" "fwupd" "disabledPlugins" ])
+ (mkRenamedOptionModule [ "services" "fwupd" "blacklistDevices"] [ "services" "fwupd" "daemonSettings" "DisabledDevices" ])
+ (mkRenamedOptionModule [ "services" "fwupd" "blacklistPlugins"] [ "services" "fwupd" "daemonSettings" "DisabledPlugins" ])
+ (mkRenamedOptionModule [ "services" "fwupd" "disabledDevices" ] [ "services" "fwupd" "daemonSettings" "DisabledDevices" ])
+ (mkRenamedOptionModule [ "services" "fwupd" "disabledPlugins" ] [ "services" "fwupd" "daemonSettings" "DisabledPlugins" ])
];
###### implementation
config = mkIf cfg.enable {
# Disable test related plug-ins implicitly so that users do not have to care about them.
- services.fwupd.disabledPlugins = cfg.package.defaultDisabledPlugins;
+ services.fwupd.daemonSettings.DisabledPlugins = cfg.package.defaultDisabledPlugins;
environment.systemPackages = [ cfg.package ];
diff --git a/pkgs/applications/audio/easyeffects/default.nix b/pkgs/applications/audio/easyeffects/default.nix
index 4e65d79ab21a..1d363e4b2c77 100644
--- a/pkgs/applications/audio/easyeffects/default.nix
+++ b/pkgs/applications/audio/easyeffects/default.nix
@@ -3,9 +3,11 @@
, desktop-file-utils
, fetchFromGitHub
, calf
+, fftw
, fftwFloat
-, fmt_8
+, fmt_9
, glib
+, gsl
, gtk4
, itstool
, libadwaita
@@ -25,6 +27,7 @@
, pkg-config
, rnnoise
, rubberband
+, speex
, speexdsp
, tbb
, wrapGAppsHook4
@@ -34,13 +37,13 @@
stdenv.mkDerivation rec {
pname = "easyeffects";
- version = "6.3.0";
+ version = "7.0.0";
src = fetchFromGitHub {
owner = "wwmm";
repo = "easyeffects";
rev = "v${version}";
- sha256 = "sha256-OLxuE1jiALuKlC9U9esVlhaMBEaoZyNae8OO8upE4ZM=";
+ sha256 = "sha256-SjhJj5kClPd8DT1vzbSdqJ9AJw0XiX9Q8/R8SDnxGPQ=";
};
nativeBuildInputs = [
@@ -53,9 +56,11 @@ stdenv.mkDerivation rec {
];
buildInputs = [
+ fftw
fftwFloat
- fmt_8
+ fmt_9
glib
+ gsl
gtk4
libadwaita
libbs2b
@@ -69,6 +74,7 @@ stdenv.mkDerivation rec {
pipewire
rnnoise
rubberband
+ speex
speexdsp
tbb
zita-convolver
diff --git a/pkgs/applications/editors/jove/default.nix b/pkgs/applications/editors/jove/default.nix
index 01a428a9fd68..ca494a37fa85 100644
--- a/pkgs/applications/editors/jove/default.nix
+++ b/pkgs/applications/editors/jove/default.nix
@@ -8,13 +8,13 @@
stdenv.mkDerivation (finalAttrs: {
pname = "jove";
- version = "4.17.4.7";
+ version = "4.17.4.8";
src = fetchFromGitHub {
owner = "jonmacs";
repo = "jove";
rev = finalAttrs.version;
- sha256 = "sha256-a8amp8JAI25XIeL8MzvJEAvv6B0oIaQvUOQlAaS3PeI=";
+ sha256 = "sha256-/n/TgVqyG/WeK+/DZqFZCdkQR4SD5+YmljLlzAehMvw=";
};
nativeBuildInputs = [ makeWrapper ];
diff --git a/pkgs/applications/emulators/dosbox/default.nix b/pkgs/applications/emulators/dosbox/default.nix
index b197742ce276..852586cc6986 100644
--- a/pkgs/applications/emulators/dosbox/default.nix
+++ b/pkgs/applications/emulators/dosbox/default.nix
@@ -2,7 +2,7 @@
, stdenv
, fetchurl
, autoreconfHook
-, SDL_compat
+, SDL
, SDL_net
, SDL_sound
, copyDesktopItems
@@ -29,7 +29,7 @@ stdenv.mkDerivation rec {
];
buildInputs = [
- SDL_compat
+ SDL
SDL_net
SDL_sound
libGL
diff --git a/pkgs/applications/graphics/inkscape/default.nix b/pkgs/applications/graphics/inkscape/default.nix
index 8a40bac446e8..6444537cac29 100644
--- a/pkgs/applications/graphics/inkscape/default.nix
+++ b/pkgs/applications/graphics/inkscape/default.nix
@@ -5,7 +5,6 @@
, cairo
, cmake
, fetchurl
-, fetchpatch
, gettext
, ghostscript
, glib
@@ -59,11 +58,11 @@ let
in
stdenv.mkDerivation rec {
pname = "inkscape";
- version = "1.2.1";
+ version = "1.2.2";
src = fetchurl {
url = "https://media.inkscape.org/dl/resources/file/inkscape-${version}.tar.xz";
- sha256 = "Rs59oOunykutwdtw6cu2fgrfm7NCaH3G4ItcohuNTBs=";
+ sha256 = "oMf9DQPAohU15kjvMB3PgN18/B81ReUQZfvxuj7opcQ=";
};
# Inkscape hits the ARGMAX when linking on macOS. It appears to be
@@ -79,12 +78,6 @@ stdenv.mkDerivation rec {
# e.g., those from the "Effects" menu.
python3 = "${python3Env}/bin/python";
})
-
- # Fix build with Poppler 22.09
- (fetchpatch {
- url = "https://github.com/archlinux/svntogit-packages/raw/b2f65dfb60ae0c8cd6cd9affd3d71064082a6201/trunk/inkscape-1.2.1-poppler-22.09.0.patch";
- sha256 = "pArvsS/qoCTMAisF8yj3agZKrb90zRFZkck1TX0KeGc=";
- })
];
postPatch = ''
diff --git a/pkgs/applications/networking/headlines/default.nix b/pkgs/applications/networking/headlines/default.nix
new file mode 100644
index 000000000000..ed26c6f60de2
--- /dev/null
+++ b/pkgs/applications/networking/headlines/default.nix
@@ -0,0 +1,72 @@
+{ lib
+, stdenv
+, cmake
+, pkg-config
+, libmicrohttpd
+, curl
+, openssl
+, jsoncpp
+, libxml2
+, gst_all_1
+, boost
+, websocketpp
+, libadwaita
+, gtkmm4
+, libsecret
+, fetchFromGitLab
+, makeWrapper
+, xdg-utils
+, youtube-dl
+, ffmpeg
+}:
+
+stdenv.mkDerivation rec {
+ pname = "headlines";
+ version = "0.7.2";
+
+ src = fetchFromGitLab {
+ owner = "caveman250";
+ repo = "Headlines";
+ rev = version;
+ sha256 = "sha256-wamow0UozX5ecKbXWOgsWCerInL4J0gK0+Muf+eoO9k=";
+ };
+
+ nativeBuildInputs = [
+ cmake
+ pkg-config
+ makeWrapper
+ ];
+
+ buildInputs = [
+ libmicrohttpd
+ curl
+ openssl
+ jsoncpp
+ libxml2
+ boost
+ websocketpp
+ libadwaita
+ gtkmm4
+ libsecret
+ ] ++ (with gst_all_1; [
+ gstreamer
+ gst-libav
+ gst-plugins-base
+ (gst-plugins-good.override { gtkSupport = true; })
+ gst-plugins-bad
+ ]);
+
+ postFixup = ''
+ wrapProgram "$out/bin/headlines" \
+ --prefix PATH : "${lib.makeBinPath [ xdg-utils youtube-dl ffmpeg ]}" \
+ --prefix GST_PLUGIN_SYSTEM_PATH_1_0 : "$GST_PLUGIN_SYSTEM_PATH_1_0"
+ '';
+
+ meta = with lib; {
+ description = "GTK4 / Libadwaita Reddit client written in C++";
+ homepage = "https://gitlab.com/caveman250/Headlines";
+ license = licenses.gpl3Plus;
+ platforms = platforms.linux;
+ maintainers = with maintainers; [ chuangzhu ];
+ };
+}
diff --git a/pkgs/applications/networking/instant-messengers/jami/default.nix b/pkgs/applications/networking/instant-messengers/jami/default.nix
index 92fbe4d45e17..d4a1e8749ecf 100644
--- a/pkgs/applications/networking/instant-messengers/jami/default.nix
+++ b/pkgs/applications/networking/instant-messengers/jami/default.nix
@@ -63,13 +63,13 @@ rec {
patch-src = src + "/daemon/contrib/src/pjproject/";
in
rec {
- version = "513a3f14c44b2c2652f9219ec20dea64b236b713";
+ version = "eae25732568e600d248aa8c226271ff6b81df170";
src = fetchFromGitHub {
owner = "savoirfairelinux";
repo = "pjproject";
rev = version;
- sha256 = "sha256-93AlJGMnlzJMrJquelpHQQKjhEgfpTFXTMqkBnm87u8=";
+ sha256 = "sha256-N7jn4qen+PgFiVkTFi2HSWhx2QPHwAYMtnrpE/ptDVc=";
};
patches = (map (x: patch-src + x) (readLinesToList ./config/pjsip_patches));
diff --git a/pkgs/applications/office/banking/default.nix b/pkgs/applications/office/banking/default.nix
index d0a08b9373ab..1874521cb0cc 100644
--- a/pkgs/applications/office/banking/default.nix
+++ b/pkgs/applications/office/banking/default.nix
@@ -18,14 +18,14 @@
python3.pkgs.buildPythonApplication rec {
pname = "banking";
- version = "0.5.1";
+ version = "0.6.0";
format = "other";
src = fetchFromGitLab {
owner = "tabos";
repo = "banking";
rev = version;
- sha256 = "sha256-tZlBpDcwQ/aWroP2sFQBZcvmBD26PiY7q/8xFA8GnVc=";
+ hash = "sha256-x/um40sRD58d5LuuJlyietCV1Rw4H5VSO0I3ZwD5kO8=";
};
postPatch = ''
@@ -54,8 +54,8 @@ python3.pkgs.buildPythonApplication rec {
cryptography
fints
mt-940
+ onetimepad
pygobject3
- pysqlitecipher
schwifty
];
diff --git a/pkgs/applications/system/thumbdrives/default.nix b/pkgs/applications/system/thumbdrives/default.nix
new file mode 100644
index 000000000000..d70ea9580629
--- /dev/null
+++ b/pkgs/applications/system/thumbdrives/default.nix
@@ -0,0 +1,62 @@
+{ lib
+, python3
+, fetchFromSourcehut
+, gtk3
+, libhandy_0
+, gobject-introspection
+, meson
+, pkg-config
+, ninja
+, gettext
+, glib
+, desktop-file-utils
+, wrapGAppsHook
+}:
+
+python3.pkgs.buildPythonApplication rec {
+ pname = "thumbdrives";
+ version = "0.3.1";
+
+ format = "other";
+
+ src = fetchFromSourcehut {
+ owner = "~martijnbraam";
+ repo = pname;
+ rev = version;
+ sha256 = "sha256-CPZKswbvsG61A6J512FOCKAntoJ0sUb2s+MKb0rO+Xw=";
+ };
+
+ postPatch = ''
+ patchShebangs build-aux/meson
+ '';
+
+ nativeBuildInputs = [
+ meson
+ pkg-config
+ ninja
+ gettext
+ glib
+ gtk3
+ desktop-file-utils
+ wrapGAppsHook
+ gobject-introspection
+ ];
+
+ buildInputs = [
+ gtk3
+ libhandy_0
+ ];
+
+ propagatedBuildInputs = with python3.pkgs; [
+ pygobject3
+ pyxdg
+ ];
+
+ meta = with lib; {
+ description = "USB mass storage emulator for Linux handhelds";
+ homepage = "https://sr.ht/~martijnbraam/thumbdrives/";
+ license = licenses.mit;
+ maintainers = with maintainers; [ chuangzhu ];
+ platforms = platforms.linux;
+ };
+}
diff --git a/pkgs/development/compilers/gleam/default.nix b/pkgs/development/compilers/gleam/default.nix
index 4df28fd739ed..3f3148371742 100644
--- a/pkgs/development/compilers/gleam/default.nix
+++ b/pkgs/development/compilers/gleam/default.nix
@@ -2,13 +2,13 @@
rustPlatform.buildRustPackage rec {
pname = "gleam";
- version = "0.25.0";
+ version = "0.25.1";
src = fetchFromGitHub {
owner = "gleam-lang";
repo = pname;
rev = "v${version}";
- sha256 = "sha256-LLl3T7VvDyyeq47vgZPkQhcPk2yZMRsCta8EqduNvuY=";
+ sha256 = "sha256-PzvFX1ssBPXhHBNGK38y427HYJ9Q40c4w2mqGZ/2rtI=";
};
nativeBuildInputs = [ pkg-config ];
@@ -16,7 +16,7 @@ rustPlatform.buildRustPackage rec {
buildInputs = [ openssl ] ++
lib.optionals stdenv.isDarwin [ Security libiconv ];
- cargoSha256 = "sha256-vMgU66LhhRrSA9Dx3eyVmUwrYKVtAfE12tQC8WzTimo=";
+ cargoSha256 = "sha256-NeNpT/yOXE70ElawrOGBc4G5bN2ohzYVVUtF4yVCJOo=";
meta = with lib; {
description = "A statically typed language for the Erlang VM";
diff --git a/pkgs/development/compilers/llvm/14/clang/default.nix b/pkgs/development/compilers/llvm/14/clang/default.nix
index 6086c65dca16..55d879fb76e4 100644
--- a/pkgs/development/compilers/llvm/14/clang/default.nix
+++ b/pkgs/development/compilers/llvm/14/clang/default.nix
@@ -26,9 +26,6 @@ let
buildInputs = [ libxml2 libllvm ];
- # workaround https://github.com/NixOS/nixpkgs/issues/201254
- NIX_LDFLAGS = if stdenv.isLinux && stdenv.isAarch64 && stdenv.cc.isGNU then "-lgcc" else null;
-
cmakeFlags = [
"-DCMAKE_CXX_FLAGS=-std=c++14"
"-DCLANGD_BUILD_XPC=OFF"
diff --git a/pkgs/development/compilers/llvm/14/compiler-rt/default.nix b/pkgs/development/compilers/llvm/14/compiler-rt/default.nix
index 994d6eaaad6a..4351c56ef530 100644
--- a/pkgs/development/compilers/llvm/14/compiler-rt/default.nix
+++ b/pkgs/development/compilers/llvm/14/compiler-rt/default.nix
@@ -35,9 +35,6 @@ stdenv.mkDerivation {
"-DSCUDO_DEFAULT_OPTIONS=DeleteSizeMismatch=0:DeallocationTypeMismatch=0"
];
- # workaround https://github.com/NixOS/nixpkgs/issues/201254
- NIX_LDFLAGS = if stdenv.isLinux && stdenv.isAarch64 && stdenv.cc.isGNU then "-lgcc" else null;
-
cmakeFlags = [
"-DCOMPILER_RT_DEFAULT_TARGET_ONLY=ON"
"-DCMAKE_C_COMPILER_TARGET=${stdenv.hostPlatform.config}"
diff --git a/pkgs/development/compilers/llvm/14/lld/default.nix b/pkgs/development/compilers/llvm/14/lld/default.nix
index 8938c5de93f5..2e0d893c7feb 100644
--- a/pkgs/development/compilers/llvm/14/lld/default.nix
+++ b/pkgs/development/compilers/llvm/14/lld/default.nix
@@ -34,9 +34,6 @@ stdenv.mkDerivation rec {
nativeBuildInputs = [ cmake ];
buildInputs = [ libllvm libxml2 ];
- # workaround https://github.com/NixOS/nixpkgs/issues/201254
- NIX_LDFLAGS = if stdenv.isLinux && stdenv.isAarch64 && stdenv.cc.isGNU then "-lgcc" else null;
-
cmakeFlags = lib.optionals (stdenv.hostPlatform != stdenv.buildPlatform) [
"-DLLVM_TABLEGEN_EXE=${buildLlvmTools.llvm}/bin/llvm-tblgen"
];
diff --git a/pkgs/development/compilers/llvm/14/lldb/default.nix b/pkgs/development/compilers/llvm/14/lldb/default.nix
index 28d3a2bd3ff4..2493dcde0c84 100644
--- a/pkgs/development/compilers/llvm/14/lldb/default.nix
+++ b/pkgs/development/compilers/llvm/14/lldb/default.nix
@@ -86,9 +86,6 @@ stdenv.mkDerivation (rec {
hardeningDisable = [ "format" ];
- # workaround https://github.com/NixOS/nixpkgs/issues/201254
- NIX_LDFLAGS = if stdenv.isLinux && stdenv.isAarch64 && stdenv.cc.isGNU then "-lgcc" else null;
-
cmakeFlags = [
"-DLLDB_INCLUDE_TESTS=${if doCheck then "YES" else "NO"}"
"-DLLVM_ENABLE_RTTI=OFF"
diff --git a/pkgs/development/compilers/llvm/14/llvm/default.nix b/pkgs/development/compilers/llvm/14/llvm/default.nix
index 4cc6c80dd4aa..673cd31460e8 100644
--- a/pkgs/development/compilers/llvm/14/llvm/default.nix
+++ b/pkgs/development/compilers/llvm/14/llvm/default.nix
@@ -129,9 +129,6 @@ in stdenv.mkDerivation (rec {
# E.g. mesa.drivers use the build-id as a cache key (see #93946):
LDFLAGS = optionalString (enableSharedLibraries && !stdenv.isDarwin) "-Wl,--build-id=sha1";
- # workaround https://github.com/NixOS/nixpkgs/issues/201254
- NIX_LDFLAGS = if stdenv.isLinux && stdenv.isAarch64 && stdenv.cc.isGNU then "-lgcc" else null;
-
cmakeFlags = with stdenv; let
# These flags influence llvm-config's BuildVariables.inc in addition to the
# general build. We need to make sure these are also passed via
diff --git a/pkgs/development/interpreters/python/cpython/2.7/default.nix b/pkgs/development/interpreters/python/cpython/2.7/default.nix
index 684088186a0a..31798a719ec4 100644
--- a/pkgs/development/interpreters/python/cpython/2.7/default.nix
+++ b/pkgs/development/interpreters/python/cpython/2.7/default.nix
@@ -31,6 +31,10 @@
, rebuildBytecode ? true
, reproducibleBuild ? false
, enableOptimizations ? false
+, strip2to3 ? false
+, stripConfig ? false
+, stripIdlelib ? false
+, stripTests ? false
, pythonAttr ? "python${sourceVersion.major}${sourceVersion.minor}"
}:
@@ -318,6 +322,16 @@ in with passthru; stdenv.mkDerivation ({
postFixup = ''
# Include a sitecustomize.py file. Note it causes an error when it's in postInstall with 2.7.
cp ${../../sitecustomize.py} $out/${sitePackages}/sitecustomize.py
+ '' + optionalString strip2to3 ''
+ rm -R $out/bin/2to3 $out/lib/python*/lib2to3
+ '' + optionalString stripConfig ''
+ rm -R $out/bin/python*-config $out/lib/python*/config-*
+ '' + optionalString stripIdlelib ''
+ # Strip IDLE
+ rm -R $out/bin/idle* $out/lib/python*/idlelib
+ '' + optionalString stripTests ''
+ # Strip tests
+ rm -R $out/lib/python*/test $out/lib/python*/**/test{,s}
'';
enableParallelBuilding = true;
diff --git a/pkgs/development/libraries/crocoddyl/default.nix b/pkgs/development/libraries/crocoddyl/default.nix
new file mode 100644
index 000000000000..2a8267f9d6b9
--- /dev/null
+++ b/pkgs/development/libraries/crocoddyl/default.nix
@@ -0,0 +1,49 @@
+{ lib
+, stdenv
+, fetchFromGitHub
+, cmake
+, example-robot-data
+, pinocchio
+, pythonSupport ? false
+, python3Packages
+}:
+
+stdenv.mkDerivation rec {
+ pname = "crocoddyl";
+ version = "1.9.0";
+
+ src = fetchFromGitHub {
+ owner = "loco-3d";
+ repo = pname;
+ rev = "v${version}";
+ sha256 = "sha256-IQ+8ZZXVTTRFa4uGetpylRab4P9MSTU2YtytYA3z6ys=";
+ fetchSubmodules = true;
+ };
+
+ strictDeps = true;
+
+ nativeBuildInputs = [
+ cmake
+ ];
+
+ propagatedBuildInputs = lib.optionals (!pythonSupport) [
+ example-robot-data
+ pinocchio
+ ] ++ lib.optionals pythonSupport [
+ python3Packages.example-robot-data
+ python3Packages.pinocchio
+ ];
+
+ cmakeFlags = lib.optionals (!pythonSupport) [
+ "-DBUILD_EXAMPLES=OFF"
+ "-DBUILD_PYTHON_INTERFACE=OFF"
+ ];
+
+ meta = with lib; {
+ description = "Crocoddyl optimal control library";
+ homepage = "https://github.com/loco-3d/crocoddyl";
+ license = licenses.bsd3;
+ maintainers = with maintainers; [ wegank ];
+ platforms = platforms.unix;
+ };
+}
diff --git a/pkgs/development/libraries/example-robot-data/default.nix b/pkgs/development/libraries/example-robot-data/default.nix
new file mode 100644
index 000000000000..08a650dbca00
--- /dev/null
+++ b/pkgs/development/libraries/example-robot-data/default.nix
@@ -0,0 +1,42 @@
+{ lib
+, stdenv
+, fetchFromGitHub
+, cmake
+, pythonSupport ? false
+, python3Packages
+}:
+
+stdenv.mkDerivation rec {
+ pname = "example-robot-data";
+ version = "4.0.3";
+
+ src = fetchFromGitHub {
+ owner = "Gepetto";
+ repo = pname;
+ rev = "v${version}";
+ fetchSubmodules = true;
+ sha256 = "sha256-rxVyka8tcF/CmGTVNyh3FPR1LVa6JOAN+9zjElgqCak=";
+ };
+
+ strictDeps = true;
+
+ nativeBuildInputs = [
+ cmake
+ ];
+
+ buildInputs = lib.optionals pythonSupport [
+ python3Packages.pinocchio
+ ];
+
+ cmakeFlags = lib.optionals (!pythonSupport) [
+ "-DBUILD_PYTHON_INTERFACE=OFF"
+ ];
+
+ meta = with lib; {
+ description = "Set of robot URDFs for benchmarking and developed examples.";
+ homepage = "https://github.com/Gepetto/example-robot-data";
+ license = licenses.bsd3;
+ maintainers = with maintainers; [ wegank ];
+ platforms = platforms.unix;
+ };
+}
diff --git a/pkgs/development/libraries/lib2geom/default.nix b/pkgs/development/libraries/lib2geom/default.nix
index b09e7dcb739a..6e5f6944f497 100644
--- a/pkgs/development/libraries/lib2geom/default.nix
+++ b/pkgs/development/libraries/lib2geom/default.nix
@@ -15,7 +15,7 @@
stdenv.mkDerivation rec {
pname = "lib2geom";
- version = "1.2";
+ version = "1.2.2";
outputs = [ "out" "dev" ];
@@ -23,7 +23,7 @@ stdenv.mkDerivation rec {
owner = "inkscape";
repo = "lib2geom";
rev = "refs/tags/${version}";
- sha256 = "sha256-SNo5YT7o29zdxkHLuy9MT88qBg/U1Wwa3BWShF5ACTc=";
+ sha256 = "sha256-xkUxcAk8KJkL482R7pvgmCT+5I8aUMm/q25pvK3ZPuY=";
};
patches = [
diff --git a/pkgs/development/libraries/pinocchio/default.nix b/pkgs/development/libraries/pinocchio/default.nix
new file mode 100644
index 000000000000..8b48e74476a6
--- /dev/null
+++ b/pkgs/development/libraries/pinocchio/default.nix
@@ -0,0 +1,57 @@
+{ lib
+, stdenv
+, fetchFromGitHub
+, cmake
+, boost
+, eigen
+, urdfdom
+, pythonSupport ? false
+, python3Packages
+}:
+
+stdenv.mkDerivation rec {
+ pname = "pinocchio";
+ version = "2.6.12";
+
+ src = fetchFromGitHub {
+ owner = "stack-of-tasks";
+ repo = pname;
+ rev = "v${version}";
+ fetchSubmodules = true;
+ sha256 = "sha256-DJX/njNX8l7ngSl3yCeN7ZoQaH65pQTsZrKwmY7EZ+E=";
+ };
+
+ # error: use of undeclared identifier '__sincos'
+ postPatch = lib.optionalString (stdenv.isDarwin && stdenv.isx86_64) ''
+ substituteInPlace src/math/sincos.hpp \
+ --replace "__APPLE__" "0"
+ '';
+
+ strictDeps = true;
+
+ nativeBuildInputs = [
+ cmake
+ ];
+
+ propagatedBuildInputs = [
+ urdfdom
+ ] ++ lib.optionals (!pythonSupport) [
+ boost
+ eigen
+ ] ++ lib.optionals pythonSupport [
+ python3Packages.boost
+ python3Packages.eigenpy
+ ];
+
+ cmakeFlags = lib.optionals (!pythonSupport) [
+ "-DBUILD_PYTHON_INTERFACE=OFF"
+ ];
+
+ meta = with lib; {
+ description = "A fast and flexible implementation of Rigid Body Dynamics algorithms and their analytical derivatives";
+ homepage = "https://github.com/stack-of-tasks/pinocchio";
+ license = licenses.bsd2;
+ maintainers = with maintainers; [ wegank ];
+ platforms = platforms.unix;
+ };
+}
diff --git a/pkgs/development/libraries/pipewire/wireplumber.nix b/pkgs/development/libraries/pipewire/wireplumber.nix
index 5770866ebbed..8ea1361c2443 100644
--- a/pkgs/development/libraries/pipewire/wireplumber.nix
+++ b/pkgs/development/libraries/pipewire/wireplumber.nix
@@ -26,7 +26,7 @@ let
in
stdenv.mkDerivation rec {
pname = "wireplumber";
- version = "0.4.12";
+ version = "0.4.13";
outputs = [ "out" "dev" ] ++ lib.optional enableDocs "doc";
@@ -35,7 +35,7 @@ stdenv.mkDerivation rec {
owner = "pipewire";
repo = "wireplumber";
rev = version;
- sha256 = "sha256-2qM6sX807v/3DZXTuBvUSGV8+cPB87rWYb+HTDCm3kw=";
+ sha256 = "sha256-Zz8N6OPwZ4Dwaygiy46C3sN9zPGC12+55S/qns+S+h4=";
};
nativeBuildInputs = [
diff --git a/pkgs/development/libraries/science/math/petsc/default.nix b/pkgs/development/libraries/science/math/petsc/default.nix
index e847d1decd24..ae95fefe0e63 100644
--- a/pkgs/development/libraries/science/math/petsc/default.nix
+++ b/pkgs/development/libraries/science/math/petsc/default.nix
@@ -67,11 +67,6 @@ stdenv.mkDerivation rec {
configureScript = "python ./configure";
- # disable stackprotector on aarch64-darwin for now
- # https://github.com/NixOS/nixpkgs/issues/158730
- # see https://github.com/NixOS/nixpkgs/issues/127608 for a similar issue
- hardeningDisable = lib.optionals (stdenv.isAarch64 && stdenv.isDarwin) [ "stackprotector" ];
-
enableParallelBuilding = true;
doCheck = stdenv.hostPlatform == stdenv.buildPlatform;
diff --git a/pkgs/development/libraries/toml11/default.nix b/pkgs/development/libraries/toml11/default.nix
new file mode 100644
index 000000000000..641b72aa1e8c
--- /dev/null
+++ b/pkgs/development/libraries/toml11/default.nix
@@ -0,0 +1,47 @@
+{ lib
+, stdenv
+, fetchFromGitHub
+, cmake
+}:
+
+stdenv.mkDerivation (finalAttrs: {
+ pname = "toml11";
+ version = "3.7.1";
+
+ src = fetchFromGitHub {
+ owner = "ToruNiina";
+ repo = "toml11";
+ rev = "v${finalAttrs.version}";
+ hash = "sha256-HnhXBvIjo1JXhp+hUQvjs83t5IBVbNN6o3ZGhB4WESQ=";
+ };
+
+ nativeBuildInputs = [
+ cmake
+ ];
+
+ meta = with lib; {
+ homepage = "https://github.com/ToruNiina/toml11";
+ description = "TOML for Modern C++";
+ longDescription = ''
+ toml11 is a C++11 (or later) header-only toml parser/encoder depending
+ only on C++ standard library.
+
+ - It is compatible to the latest version of TOML v1.0.0.
+ - It is one of the most TOML standard compliant libraries, tested with
+ the language agnostic test suite for TOML parsers by BurntSushi.
+ - It shows highly informative error messages.
+ - It has configurable container. You can use any random-access containers
+ and key-value maps as backend containers.
+ - It optionally preserves comments without any overhead.
+ - It has configurable serializer that supports comments, inline tables,
+ literal strings and multiline strings.
+ - It supports user-defined type conversion from/into toml values.
+ - It correctly handles UTF-8 sequences, with or without BOM, both on posix
+ and Windows.
+ '';
+ license = licenses.mit;
+ maintainers = with maintainers; [ AndersonTorres ];
+ platforms = platforms.unix;
+ };
+})
+# TODO [ AndersonTorres ]: tests
diff --git a/pkgs/development/ocaml-modules/pyml/default.nix b/pkgs/development/ocaml-modules/pyml/default.nix
index 97fcf1d5caa4..9eba3ab3185b 100644
--- a/pkgs/development/ocaml-modules/pyml/default.nix
+++ b/pkgs/development/ocaml-modules/pyml/default.nix
@@ -1,23 +1,37 @@
-{ stdenv, lib, fetchFromGitHub, ocaml, findlib, utop, python3, stdcompat, ncurses }:
+{ buildDunePackage
+, lib
+, fetchFromGitHub
+, fetchpatch
+, utop
+, python3
+, stdcompat
+}:
-stdenv.mkDerivation rec {
+buildDunePackage rec {
pname = "pyml";
- version = "20220615";
+ version = "20220905";
src = fetchFromGitHub {
- owner = "thierry-martinez";
- repo = pname;
- rev = version;
- sha256 = "sha256-my/xn9vrYTcHyjXGBNamgqpBz2/6bTyQHuE9ViVGLjw=";
+ owner = "thierry-martinez";
+ repo = "pyml";
+ rev = version;
+ sha256 = "PL4tFIKQLRutSn9Sf84/ImJv0DqkstNnJaNBqWDTKDQ=";
};
- nativeBuildInputs = [
- ocaml
- findlib
+ patches = [
+ # Fixes test crash.
+ # https://github.com/thierry-martinez/pyml/issues/85
+ (fetchpatch {
+ url = "https://github.com/thierry-martinez/pyml/commit/a0bc5aca8632bea273f869d622cad2f55e754a7c.patch";
+ sha256 = "bOqAokm5DE5rlvkBMQZtwMppRmoK9cvjJeGeP6BusnE=";
+ excludes = [
+ "CHANGES.md"
+ ];
+ })
];
+
buildInputs = [
utop
- ncurses
];
propagatedBuildInputs = [
@@ -25,24 +39,17 @@ stdenv.mkDerivation rec {
stdcompat
];
+ checkInputs = [
+ python3.pkgs.numpy
+ ];
+
strictDeps = true;
- buildPhase = ''
- make all pymltop pymlutop PREFIX=$out
- '';
-
- installPhase = ''
- runHook preInstall
- mkdir -p $out/bin
- mkdir -p $OCAMLFIND_DESTDIR/stublibs
- make install PREFIX=$out
- runHook postInstall
- '';
-
doCheck = true;
meta = {
description = "OCaml bindings for Python";
+ homepage = "https://github.com/thierry-martinez/pyml";
license = lib.licenses.bsd2;
};
}
diff --git a/pkgs/development/ocaml-modules/stdcompat/default.nix b/pkgs/development/ocaml-modules/stdcompat/default.nix
index 3630be368e55..b8dcc81bfe7e 100644
--- a/pkgs/development/ocaml-modules/stdcompat/default.nix
+++ b/pkgs/development/ocaml-modules/stdcompat/default.nix
@@ -1,29 +1,25 @@
-{ stdenv, lib, fetchurl
-, ocaml, findlib
+{ buildDunePackage
+, lib
+, fetchurl
}:
-stdenv.mkDerivation rec {
- pname = "ocaml${ocaml.version}-stdcompat";
- version = "18";
+buildDunePackage rec {
+ pname = "stdcompat";
+ version = "19";
src = fetchurl {
url = "https://github.com/thierry-martinez/stdcompat/releases/download/v${version}/stdcompat-${version}.tar.gz";
- sha256 = "sha256:01y67rndjlzfp5zq0gbqpg9skqq2hfbvhbq9lfhhk5xidr98sfj8";
+ sha256 = "sha256-DKQGd4nnIN6SPls6hcA/2Jvc7ivYNpeMU6rYsVc1ClU=";
};
- nativeBuildInputs = [ ocaml findlib ];
-
strictDeps = true;
- # build fails otherwise
- enableParallelBuilding = false;
-
- configureFlags = [ "--libdir=$(OCAMLFIND_DESTDIR)" ];
+ # Otherwise ./configure script will run and create files conflicting with dune.
+ dontConfigure = true;
meta = {
homepage = "https://github.com/thierry-martinez/stdcompat";
license = lib.licenses.bsd2;
maintainers = [ lib.maintainers.vbgl ];
- inherit (ocaml.meta) platforms;
};
}
diff --git a/pkgs/development/python-modules/click-command-tree/default.nix b/pkgs/development/python-modules/click-command-tree/default.nix
new file mode 100644
index 000000000000..14903853646e
--- /dev/null
+++ b/pkgs/development/python-modules/click-command-tree/default.nix
@@ -0,0 +1,49 @@
+{ lib
+, buildPythonPackage
+, fetchFromGitHub
+, fetchpatch
+, click
+, pytestCheckHook
+}:
+
+buildPythonPackage rec {
+ pname = "click-command-tree";
+ version = "1.1.0";
+ format = "setuptools";
+
+ src = fetchFromGitHub {
+ owner = "whwright";
+ repo = pname;
+ rev = version;
+ hash = "sha256-vFOcn+ibyLZnhU3OQMtnHI04UqAY2/CCvhq4EEU4XFo=";
+ };
+
+ patches = [
+ (fetchpatch {
+ name = "remove-setup-downloading-flake8.patch";
+ url = "https://github.com/whwright/click-command-tree/commit/1ecfcfa29bf01e1131e6ec712bd7338ac1283dc8.patch";
+ hash = "sha256-u5jsNfEo1+XNlkVGPCM/rsDPnYko6cr2z2si9nq+sLA=";
+ })
+ ];
+
+ propagatedBuildInputs = [
+ click
+ ];
+
+ checkInputs = [
+ pytestCheckHook
+ ];
+
+ pytestFlagsArray = [
+ "tests.py"
+ ];
+
+ pythonImportsCheck = [ "click_command_tree" ];
+
+ meta = with lib; {
+ description = "click plugin to show the command tree of your CLI";
+ homepage = "https://github.com/whwright/click-command-tree";
+ license = licenses.mit;
+ maintainers = with maintainers; [ tjni ];
+ };
+}
diff --git a/pkgs/development/python-modules/devtools/default.nix b/pkgs/development/python-modules/devtools/default.nix
index 34004769b1fd..a6cc42dfe962 100644
--- a/pkgs/development/python-modules/devtools/default.nix
+++ b/pkgs/development/python-modules/devtools/default.nix
@@ -2,6 +2,7 @@
, asttokens
, buildPythonPackage
, executing
+, hatchling
, fetchFromGitHub
, pygments
, pytest-mock
@@ -11,18 +12,22 @@
buildPythonPackage rec {
pname = "devtools";
- version = "0.8.0";
- format = "setuptools";
+ version = "0.10.0";
+ format = "pyproject";
- disabled = pythonOlder "3.6";
+ disabled = pythonOlder "3.7";
src = fetchFromGitHub {
owner = "samuelcolvin";
repo = "python-${pname}";
rev = "v${version}";
- sha256 = "0yavcbxzxi1nfa1k326gsl03y8sadi5z5acamwd8b1bsiv15p757";
+ sha256 = "sha256-x9dL/FE94OixMAmjnmfzZUcYJBqE5P2AAIFsNJF0Fxo=";
};
+ nativeBuildInputs = [
+ hatchling
+ ];
+
propagatedBuildInputs = [
asttokens
executing
diff --git a/pkgs/development/python-modules/eigenpy/default.nix b/pkgs/development/python-modules/eigenpy/default.nix
new file mode 100644
index 000000000000..a13b8e52ed53
--- /dev/null
+++ b/pkgs/development/python-modules/eigenpy/default.nix
@@ -0,0 +1,44 @@
+{ lib
+, stdenv
+, fetchFromGitHub
+, cmake
+, boost
+, eigen
+, numpy
+}:
+
+stdenv.mkDerivation rec {
+ pname = "eigenpy";
+ version = "2.8.1";
+
+ src = fetchFromGitHub {
+ owner = "stack-of-tasks";
+ repo = pname;
+ rev = "v${version}";
+ fetchSubmodules = true;
+ sha256 = "sha256-nofB5TDvEArhPcYe/Pb1LQBC+W6MrE3NuapaZmKIO68=";
+ };
+
+ strictDeps = true;
+
+ nativeBuildInputs = [
+ cmake
+ ];
+
+ buildInputs = [
+ boost
+ ];
+
+ propagatedBuildInputs = [
+ eigen
+ numpy
+ ];
+
+ meta = with lib; {
+ description = "Bindings between Numpy and Eigen using Boost.Python";
+ homepage = "https://github.com/stack-of-tasks/eigenpy";
+ license = licenses.bsd2;
+ maintainers = with maintainers; [ wegank ];
+ platforms = platforms.unix;
+ };
+}
diff --git a/pkgs/development/python-modules/graphene/default.nix b/pkgs/development/python-modules/graphene/default.nix
index 1d10e9fcdd79..c6508cef7a7e 100644
--- a/pkgs/development/python-modules/graphene/default.nix
+++ b/pkgs/development/python-modules/graphene/default.nix
@@ -17,7 +17,7 @@
buildPythonPackage rec {
pname = "graphene";
- version = "3.2.0";
+ version = "3.2.1";
format = "setuptools";
disabled = pythonOlder "3.6";
@@ -26,7 +26,7 @@ buildPythonPackage rec {
owner = "graphql-python";
repo = "graphene";
rev = "refs/tags/v${version}";
- hash = "sha256-2o/IR6XjnS57D4ZjADrcI18acfJ+Q0zdnXeb5ZeCpM4=";
+ hash = "sha256-XnrzgPkkFsTgNE9J+eSkD8f5MokKjtZhbbE/dxNZryk=";
};
propagatedBuildInputs = [
diff --git a/pkgs/development/python-modules/h11/default.nix b/pkgs/development/python-modules/h11/default.nix
index bb61c5310354..4f34ca2daafb 100644
--- a/pkgs/development/python-modules/h11/default.nix
+++ b/pkgs/development/python-modules/h11/default.nix
@@ -4,6 +4,7 @@
, pytestCheckHook
, pythonOlder
, httpcore
+, httpx
, wsproto
}:
@@ -23,7 +24,7 @@ buildPythonPackage rec {
__darwinAllowLocalNetworking = true;
passthru.tests = {
- inherit httpcore wsproto;
+ inherit httpcore httpx wsproto;
};
meta = with lib; {
diff --git a/pkgs/development/python-modules/hahomematic/default.nix b/pkgs/development/python-modules/hahomematic/default.nix
index d3846c4efcb8..26b050ae998b 100644
--- a/pkgs/development/python-modules/hahomematic/default.nix
+++ b/pkgs/development/python-modules/hahomematic/default.nix
@@ -15,7 +15,7 @@
buildPythonPackage rec {
pname = "hahomematic";
- version = "2022.12.2";
+ version = "2022.12.3";
format = "pyproject";
disabled = pythonOlder "3.9";
@@ -24,7 +24,7 @@ buildPythonPackage rec {
owner = "danielperna84";
repo = pname;
rev = "refs/tags/${version}";
- sha256 = "sha256-mU/YOOYlXNQQyzH2t+XZEi2+w8rzcoxIIxrdwAM4C00=";
+ sha256 = "sha256-6xCPkB2QydoJrvwgGGJqmGaw38HCAUs2jPBuXoIBC2Q=";
};
nativeBuildInputs = [
diff --git a/pkgs/development/python-modules/httpx/default.nix b/pkgs/development/python-modules/httpx/default.nix
index 4085a2e0893f..104fabd2c50c 100644
--- a/pkgs/development/python-modules/httpx/default.nix
+++ b/pkgs/development/python-modules/httpx/default.nix
@@ -8,8 +8,11 @@
, click
, fetchFromGitHub
, h2
+, hatch-fancy-pypi-readme
+, hatchling
, httpcore
, isPyPy
+, multipart
, pygments
, python
, pythonOlder
@@ -26,8 +29,8 @@
buildPythonPackage rec {
pname = "httpx";
- version = "0.23.0";
- format = "setuptools";
+ version = "0.23.1";
+ format = "pyproject";
disabled = pythonOlder "3.7";
@@ -35,9 +38,14 @@ buildPythonPackage rec {
owner = "encode";
repo = pname;
rev = version;
- hash = "sha256-s11Yeizm3y3w5D6ACQ2wp/KJ0+1ALY/R71IlTP2pMC4=";
+ hash = "sha256-1gRBHbGFUkaFvVgHHoXfpo9j0L074SyevFwMY202+uk=";
};
+ nativeBuildInputs = [
+ hatch-fancy-pypi-readme
+ hatchling
+ ];
+
propagatedBuildInputs = [
certifi
httpcore
@@ -69,6 +77,7 @@ buildPythonPackage rec {
checkInputs = [
chardet
+ multipart
pytestCheckHook
pytest-asyncio
pytest-trio
@@ -79,7 +88,7 @@ buildPythonPackage rec {
++ passthru.optional-dependencies.socks;
postPatch = ''
- substituteInPlace setup.py \
+ substituteInPlace pyproject.toml \
--replace "rfc3986[idna2008]>=1.3,<2" "rfc3986>=1.3"
'';
@@ -112,6 +121,7 @@ buildPythonPackage rec {
__darwinAllowLocalNetworking = true;
meta = with lib; {
+ changelog = "https://github.com/encode/httpx/blob/${src.rev}/CHANGELOG.md";
description = "The next generation HTTP client";
homepage = "https://github.com/encode/httpx";
license = licenses.bsd3;
diff --git a/pkgs/development/python-modules/jupyterlab/default.nix b/pkgs/development/python-modules/jupyterlab/default.nix
index 4bc5acb5cc42..afdcf88bde18 100644
--- a/pkgs/development/python-modules/jupyterlab/default.nix
+++ b/pkgs/development/python-modules/jupyterlab/default.nix
@@ -10,14 +10,14 @@
buildPythonPackage rec {
pname = "jupyterlab";
- version = "3.5.0";
+ version = "3.5.1";
format = "setuptools";
disabled = pythonOlder "3.7";
src = fetchPypi {
inherit pname version;
- sha256 = "sha256-4CVWyOobOGljxLRk5GGK7hU8VBawerSBQlyBegMzI6I=";
+ sha256 = "sha256-WaGy151LPr7k2ZfIvtjPRQ9GDHw19GthOpPwt3ErR/w=";
};
nativeBuildInputs = [
diff --git a/pkgs/development/python-modules/multipart/default.nix b/pkgs/development/python-modules/multipart/default.nix
new file mode 100644
index 000000000000..6d441843162d
--- /dev/null
+++ b/pkgs/development/python-modules/multipart/default.nix
@@ -0,0 +1,39 @@
+{ lib
+, buildPythonPackage
+, fetchPypi
+, fetchpatch
+, pytestCheckHook
+}:
+
+buildPythonPackage rec {
+ pname = "multipart";
+ version = "0.2.4";
+
+ format = "setuptools";
+
+ src = fetchPypi {
+ inherit pname version;
+ sha256 = "06ba205360bc7096fefe618e4f1e9b2cdb890b4f2157053a81f386912a2522cb";
+ };
+
+ patches = [
+ (fetchpatch {
+ name = "dont-test-semicolon-separators-in-urlencoded-data.patch";
+ url = "https://github.com/defnull/multipart/commit/4d4ac6b79c453918ebf40c690e8d57d982ee840b.patch";
+ hash = "sha256-rMeMhQEhonWAHzy5M8Im5mL6km5a9O0CGVOV+T3UNqo=";
+ })
+ ];
+
+ checkInputs = [
+ pytestCheckHook
+ ];
+
+ pythonImportsCheck = [ "multipart" ];
+
+ meta = {
+ description = "Parser for multipart/form-data";
+ homepage = "https://github.com/defnull/multipart";
+ license = lib.licenses.mit;
+ maintainers = with lib.maintainers; [ dotlambda ];
+ };
+}
diff --git a/pkgs/development/python-modules/pycodestyle/default.nix b/pkgs/development/python-modules/pycodestyle/default.nix
index de1dea5e066d..ed4ac3f5fbf3 100644
--- a/pkgs/development/python-modules/pycodestyle/default.nix
+++ b/pkgs/development/python-modules/pycodestyle/default.nix
@@ -29,7 +29,7 @@ buildPythonPackage rec {
pythonImportsCheck = [ "pycodestyle" ];
meta = with lib; {
- changelog = "https://github.com/PyCQA/pyflakes/blob/${version}/NEWS.rst";
+ changelog = "https://github.com/PyCQA/pycodestyle/blob/${version}/CHANGES.txt";
description = "Python style guide checker";
homepage = "https://pycodestyle.pycqa.org/";
license = licenses.mit;
diff --git a/pkgs/development/python-modules/spsdk/default.nix b/pkgs/development/python-modules/spsdk/default.nix
index 52dad183fa16..a4683a807278 100644
--- a/pkgs/development/python-modules/spsdk/default.nix
+++ b/pkgs/development/python-modules/spsdk/default.nix
@@ -1,7 +1,6 @@
{ lib
, buildPythonPackage
, fetchFromGitHub
-, fetchpatch
, dos2unix
, pythonRelaxDepsHook
, asn1crypto
@@ -9,6 +8,7 @@
, bincopy
, bitstring
, click
+, click-command-tree
, click-option-group
, cmsis-pack-manager
, commentjson
@@ -33,42 +33,32 @@
buildPythonPackage rec {
pname = "spsdk";
- version = "1.6.3";
+ version = "1.8.0";
src = fetchFromGitHub {
owner = "NXPmicro";
repo = pname;
rev = version;
- sha256 = "sha256-JMhd2XdbjEN6SUzFgcBHd/dStiuYeXXis6pfijSfUso=";
+ hash = "sha256-yCmkOrUe5XqbuHeo7F84j1gmdzpdpCRWdD9V74U64c4=";
};
- patches = [
- # https://github.com/NXPmicro/spsdk/pull/43
- (fetchpatch {
- name = "cryptography-37-compat.patch";
- url = "https://github.com/NXPmicro/spsdk/commit/a85b854de1093de593d27fa64de442224ab2e0fd.patch";
- sha256 = "sha256-4pXV/8RaNuGl7KNdoGD/8YnPQ2ZmUQOjXWA/Yy0Kxu8=";
- })
- # https://github.com/NXPmicro/spsdk/pull/41
- (fetchpatch {
- name = "blhost-click-8-1-compat.patch";
- url = "https://github.com/NXPmicro/spsdk/commit/5112b1b69aa681d265035475e73d28ea0c8cb6ab.patch";
- sha256 = "sha256-Okz6Er6OVuAA5IlB5IabSa/gUSLa+E2Ltd+J3uoIg6o=";
- })
+ nativeBuildInputs = [
+ pythonRelaxDepsHook
];
- nativeBuildInputs = [ pythonRelaxDepsHook ];
pythonRelaxDeps = [
"bincopy"
"bitstring"
"cmsis-pack-manager"
- "cryptography"
"deepmerge"
"jinja2"
"pylink-square"
"pyocd"
];
- pythonRemoveDeps = [ "pyocd-pemicro" ];
+
+ pythonRemoveDeps = [
+ "pyocd-pemicro"
+ ];
propagatedBuildInputs = [
asn1crypto
@@ -76,6 +66,7 @@ buildPythonPackage rec {
bincopy
bitstring
click
+ click-command-tree
click-option-group
cmsis-pack-manager
commentjson
@@ -101,12 +92,6 @@ buildPythonPackage rec {
voluptuous
];
- disabledTests = [
- # tests also fail on debian, so presumable they are broken
- "test_elftosb_mbi_signed"
- "test_elftosb_sb31"
- ];
-
pythonImportsCheck = [ "spsdk" ];
meta = with lib; {
diff --git a/pkgs/development/python-modules/zadnegoale/default.nix b/pkgs/development/python-modules/zadnegoale/default.nix
index 7d47cb347c8c..5b08fa950fa5 100644
--- a/pkgs/development/python-modules/zadnegoale/default.nix
+++ b/pkgs/development/python-modules/zadnegoale/default.nix
@@ -13,7 +13,7 @@
buildPythonPackage rec {
pname = "zadnegoale";
- version = "0.6.5";
+ version = "0.7.0";
format = "setuptools";
disabled = pythonOlder "3.8";
@@ -22,7 +22,7 @@ buildPythonPackage rec {
owner = "bieniu";
repo = pname;
rev = "refs/tags/${version}";
- hash = "sha256-ubBN4jvueNgReNbS+RXNDNHID0MF/rvQnb0+F4/DZaU=";
+ hash = "sha256-ij8xou8LXC4/BUTApIV6xSgb7ethwLyrHNJvBgxSBYM=";
};
propagatedBuildInputs = [
@@ -45,6 +45,7 @@ buildPythonPackage rec {
meta = with lib; {
description = "Python wrapper for getting allergen concentration data from Żadnego Ale servers";
homepage = "https://github.com/bieniu/zadnegoale";
+ changelog = "https://github.com/bieniu/zadnegoale/releases/tag/${version}";
license = licenses.asl20;
maintainers = with maintainers; [ fab ];
};
diff --git a/pkgs/development/tools/hjson-go/default.nix b/pkgs/development/tools/hjson-go/default.nix
index 7b8509173220..bab12da8eb6a 100644
--- a/pkgs/development/tools/hjson-go/default.nix
+++ b/pkgs/development/tools/hjson-go/default.nix
@@ -1,23 +1,30 @@
-{ lib, buildGoModule, fetchFromGitHub }:
+{ lib
+, buildGoModule
+, fetchFromGitHub
+}:
buildGoModule rec {
pname = "hjson-go";
- version = "4.2.0";
+ version = "4.3.0";
src = fetchFromGitHub {
owner = "hjson";
repo = pname;
rev = "v${version}";
- sha256 = "sha256-bw8dQKwHqEzBpDT+59XjzhxDrA3R0OiEUyIWMULuAQI=";
+ hash = "sha256-WR6wLa/Za5MgcH1enHG/74uq/7PdaY/OzvJdgMgDFIk=";
};
vendorSha256 = null;
- ldflags = [ "-s" "-w" ];
+ ldflags = [
+ "-s"
+ "-w"
+ ];
meta = with lib; {
description = "Utility to convert JSON to and from HJSON";
homepage = "https://hjson.github.io/";
+ changelog = "https://github.com/hjson/hjson-go/releases/tag/v${version}";
maintainers = with maintainers; [ ehmry ];
license = licenses.mit;
mainProgram = "hjson-cli";
diff --git a/pkgs/development/tools/packer/default.nix b/pkgs/development/tools/packer/default.nix
index 1d3cdf62c081..3204058326a3 100644
--- a/pkgs/development/tools/packer/default.nix
+++ b/pkgs/development/tools/packer/default.nix
@@ -7,16 +7,16 @@
buildGoModule rec {
pname = "packer";
- version = "1.8.4";
+ version = "1.8.5";
src = fetchFromGitHub {
owner = "hashicorp";
repo = "packer";
rev = "v${version}";
- sha256 = "sha256-m8PKigVm46PN55hchc5a1OUUuhxoGn3e2sMRqqvkPgs=";
+ sha256 = "sha256-jdJD7AW4IrzVl4BPdsFFrRSdCWX9l4nFM+DWIuxLiJ8=";
};
- vendorSha256 = "sha256-hSZCYSV7nMGd5KQsV+Z4ig7vk4j8cZnOvsg0DqPiEvg=";
+ vendorSha256 = "sha256-ufvWgusTMbM88F3BkJ61KM2wRSdqPOlMKqDSYf7tZQA=";
subPackages = [ "." ];
diff --git a/pkgs/misc/superd/default.nix b/pkgs/misc/superd/default.nix
new file mode 100644
index 000000000000..105d7278e5bb
--- /dev/null
+++ b/pkgs/misc/superd/default.nix
@@ -0,0 +1,43 @@
+{ lib
+, buildGoModule
+, fetchFromSourcehut
+, installShellFiles
+, scdoc
+}:
+
+buildGoModule rec {
+ pname = "superd";
+ version = "0.7";
+
+ src = fetchFromSourcehut {
+ owner = "~craftyguy";
+ repo = pname;
+ rev = version;
+ hash = "sha256-XSB6qgepWhus15lOP9GzbiNoOCSsy6xLij7ic3LFs1E=";
+ };
+
+ vendorHash = "sha256-Oa99U3THyWLjH+kWMQAHO5QAS2mmtY7M7leej+gnEqo=";
+
+ nativeBuildInputs = [
+ installShellFiles
+ scdoc
+ ];
+
+ postBuild = ''
+ make doc
+ '';
+
+ postInstall = ''
+ installManPage superd.1 superd.service.5 superctl.1
+ installShellCompletion --bash completions/bash/superctl
+ installShellCompletion --zsh completions/zsh/superctl
+ '';
+
+ meta = with lib; {
+ description = "Unprivileged user service supervisor";
+ homepage = "https://sr.ht/~craftyguy/superd/";
+ license = licenses.gpl3Plus;
+ platforms = platforms.linux;
+ maintainers = with maintainers; [ chuangzhu wentam ];
+ };
+}
diff --git a/pkgs/os-specific/linux/sgx/sdk/default.nix b/pkgs/os-specific/linux/sgx/sdk/default.nix
index 977139406fe9..5213dc1e4fda 100644
--- a/pkgs/os-specific/linux/sgx/sdk/default.nix
+++ b/pkgs/os-specific/linux/sgx/sdk/default.nix
@@ -16,7 +16,7 @@
, nasm
, ocaml
, ocamlPackages
-, openssl
+, openssl_1_1
, perl
, python3
, texinfo
@@ -84,7 +84,7 @@ stdenv.mkDerivation rec {
buildInputs = [
libtool
- openssl
+ openssl_1_1
];
BINUTILS_DIR = "${binutils}/bin";
diff --git a/pkgs/shells/zsh/zsh-forgit/default.nix b/pkgs/shells/zsh/zsh-forgit/default.nix
index 01dc6874cc46..ce99b5e34484 100644
--- a/pkgs/shells/zsh/zsh-forgit/default.nix
+++ b/pkgs/shells/zsh/zsh-forgit/default.nix
@@ -1,28 +1,39 @@
-{ stdenv, lib, fetchFromGitHub, git, fzf }:
+{ stdenv, lib, bash, fetchFromGitHub, makeWrapper, fzf, git }:
stdenv.mkDerivation rec {
pname = "zsh-forgit";
- version = "22.11.0";
+ version = "22.12.0";
src = fetchFromGitHub {
owner = "wfxr";
repo = "forgit";
rev = version;
- sha256 = "ca7EM/F0Spsdr3MbjIVwbjLVXg6/qWGczBQHLCcpU5A=";
+ sha256 = "0juBNUJW4SU3Cl6ouD+xMYzlCJOL7NAYpueZ6V56/ck=";
};
strictDeps = true;
postPatch = ''
substituteInPlace forgit.plugin.zsh \
- --replace "fzf " "${fzf}/bin/fzf " \
- --replace "git " "${git}/bin/git "
+ --replace "\$INSTALL_DIR/bin/git-forgit" "$out/bin/git-forgit"
+
+ substituteInPlace bin/git-forgit \
+ --replace "/bin/bash" "${bash}/bin/bash"
'';
dontBuild = true;
+ nativeBuildInputs = [ makeWrapper ];
+
installPhase = ''
+ runHook preInstall
+
+ install -D bin/git-forgit $out/bin/git-forgit
install -D forgit.plugin.zsh $out/share/zsh/${pname}/forgit.plugin.zsh
+ wrapProgram $out/bin/git-forgit \
+ --prefix PATH : ${lib.makeBinPath [ fzf git ]}
+
+ runHook postInstall
'';
meta = with lib; {
diff --git a/pkgs/tools/misc/ea/default.nix b/pkgs/tools/misc/ea/default.nix
new file mode 100644
index 000000000000..cbef6caebbbc
--- /dev/null
+++ b/pkgs/tools/misc/ea/default.nix
@@ -0,0 +1,31 @@
+{ lib, stdenv, fetchFromGitHub, rustPlatform, installShellFiles, libiconv }:
+
+rustPlatform.buildRustPackage rec {
+ pname = "dduan";
+ version = "0.2.1";
+
+ src = fetchFromGitHub {
+ owner = "dduan";
+ repo = "ea";
+ rev = version;
+ sha256 = "VXSSe5d7VO3LfjumzN9a7rrKRedOtOzTdLVQWgV1ED8=";
+ };
+
+ cargoSha256 = "sha256-QNj24qKZFqG4QXG6rIFV2Y/BNPTXt7HaX7smsJRrdzg=";
+
+ nativeBuildInputs = [ installShellFiles ];
+ buildInputs = lib.optionals stdenv.isDarwin [
+ libiconv
+ ];
+
+ postInstall = ''
+ installManPage docs/ea.1
+ '';
+
+ meta = with lib; {
+ description = "Makes file paths from CLI output actionable";
+ homepage = "https://github.com/dduan/ea";
+ license = with licenses; [ mit ];
+ maintainers = with maintainers; [ deejayem ];
+ };
+}
diff --git a/pkgs/tools/package-management/reuse/default.nix b/pkgs/tools/package-management/reuse/default.nix
index d3fbc6fc37bf..775b6da1707a 100644
--- a/pkgs/tools/package-management/reuse/default.nix
+++ b/pkgs/tools/package-management/reuse/default.nix
@@ -2,22 +2,26 @@
python3Packages.buildPythonApplication rec {
pname = "reuse";
- version = "1.0.0";
+ version = "1.1.0";
+ format = "pyproject";
src = fetchFromGitHub {
owner = "fsfe";
repo = "reuse-tool";
rev = "v${version}";
- sha256 = "0yplsbd5251s8cabazbdqb00jqv8ibbgal7fhj5pfxv5lsz17vkv";
+ hash = "sha256-bjUDImMFwMhRjCa7XzGlqR8h+KfTsyxonrQlRGgApwo=";
};
+ nativeBuildInputs = with python3Packages; [
+ poetry-core
+ ];
+
propagatedBuildInputs = with python3Packages; [
binaryornot
boolean-py
debian
jinja2
license-expression
- requests
setuptools
setuptools-scm
];
@@ -28,6 +32,6 @@ python3Packages.buildPythonApplication rec {
description = "A tool for compliance with the REUSE Initiative recommendations";
homepage = "https://github.com/fsfe/reuse-tool";
license = with licenses; [ asl20 cc-by-sa-40 cc0 gpl3Plus ];
- maintainers = [ maintainers.FlorianFranzen ];
+ maintainers = with maintainers; [ FlorianFranzen Luflosi ];
};
}
diff --git a/pkgs/top-level/all-packages.nix b/pkgs/top-level/all-packages.nix
index 331e9add4eef..bf52806076f2 100644
--- a/pkgs/top-level/all-packages.nix
+++ b/pkgs/top-level/all-packages.nix
@@ -468,6 +468,8 @@ with pkgs;
inherit (darwin.apple_sdk.frameworks) Security;
};
+ ea = callPackage ../tools/misc/ea { };
+
each = callPackage ../tools/text/each { };
eclipse-mat = callPackage ../development/tools/eclipse-mat { };
@@ -1962,7 +1964,9 @@ with pkgs;
dlx = callPackage ../applications/emulators/dlx { };
- dosbox = callPackage ../applications/emulators/dosbox { };
+ dosbox = callPackage ../applications/emulators/dosbox {
+ SDL = if stdenv.isDarwin then SDL else SDL_compat;
+ };
dosbox-staging = callPackage ../applications/emulators/dosbox-staging { };
@@ -12201,6 +12205,8 @@ with pkgs;
threema-desktop = callPackage ../applications/networking/instant-messengers/threema-desktop { };
+ thumbdrives = callPackage ../applications/system/thumbdrives { };
+
tidy-viewer = callPackage ../tools/text/tidy-viewer { };
tiled = libsForQt5.callPackage ../applications/editors/tiled { };
@@ -14933,8 +14939,6 @@ with pkgs;
buildLlvmTools = buildPackages.llvmPackages_14.tools;
targetLlvmLibraries = targetPackages.llvmPackages_14.libraries or llvmPackages_14.libraries;
targetLlvm = targetPackages.llvmPackages_14.llvm or llvmPackages_14.llvm;
- } // lib.optionalAttrs (stdenv.hostPlatform.isAarch64 && stdenv.hostPlatform.isLinux && buildPackages.stdenv.cc.isGNU) {
- stdenv = gcc11Stdenv;
}));
llvmPackages_latest = llvmPackages_14;
@@ -18788,6 +18792,8 @@ with pkgs;
croaring = callPackage ../development/libraries/croaring { };
+ crocoddyl = callPackage ../development/libraries/crocoddyl { };
+
crossguid = callPackage ../development/libraries/crossguid { };
cryptopp = callPackage ../development/libraries/crypto++ { };
@@ -18959,6 +18965,8 @@ with pkgs;
liberasurecode = callPackage ../applications/misc/liberasurecode { };
+ example-robot-data = callPackage ../development/libraries/example-robot-data { };
+
exiv2 = callPackage ../development/libraries/exiv2 { };
expat = callPackage ../development/libraries/expat { };
@@ -22050,6 +22058,8 @@ with pkgs;
pico-sdk = callPackage ../development/libraries/pico-sdk { };
+ pinocchio = callPackage ../development/libraries/pinocchio { };
+
pipelight = callPackage ../tools/misc/pipelight {
stdenv = stdenv_32bit;
wine-staging = pkgsi686Linux.wine-staging;
@@ -22933,6 +22943,8 @@ with pkgs;
tomlcpp = callPackage ../development/libraries/tomlcpp { };
+ toml11 = callPackage ../development/libraries/toml11 { };
+
tomlplusplus = callPackage ../development/libraries/tomlplusplus { };
tokyocabinet = callPackage ../development/libraries/tokyo-cabinet { };
@@ -29297,6 +29309,8 @@ with pkgs;
hdhomerun-config-gui = callPackage ../applications/video/hdhomerun-config-gui { };
+ headlines = callPackage ../applications/networking/headlines { };
+
hedgedoc-cli = callPackage ../tools/admin/hedgedoc-cli { };
heimer = libsForQt5.callPackage ../applications/misc/heimer { };
@@ -37146,6 +37160,8 @@ with pkgs;
stork = callPackage ../applications/misc/stork { };
+ superd = callPackage ../misc/superd { };
+
oclgrind = callPackage ../development/tools/analysis/oclgrind { };
opkg = callPackage ../tools/package-management/opkg { };
diff --git a/pkgs/top-level/python-packages.nix b/pkgs/top-level/python-packages.nix
index af567721e3d4..7b1a7e741533 100644
--- a/pkgs/top-level/python-packages.nix
+++ b/pkgs/top-level/python-packages.nix
@@ -1756,6 +1756,8 @@ self: super: with self; {
clickclick = callPackage ../development/python-modules/clickclick { };
+ click-command-tree = callPackage ../development/python-modules/click-command-tree { };
+
click-completion = callPackage ../development/python-modules/click-completion { };
click-configfile = callPackage ../development/python-modules/click-configfile { };
@@ -2022,6 +2024,11 @@ self: super: with self; {
criticality-score = callPackage ../development/python-modules/criticality-score { };
+ crocoddyl = toPythonModule (callPackage ../development/libraries/crocoddyl {
+ pythonSupport = true;
+ python3Packages = self;
+ });
+
cron-descriptor = callPackage ../development/python-modules/cron-descriptor { };
croniter = callPackage ../development/python-modules/croniter { };
@@ -2887,6 +2894,8 @@ self: super: with self; {
eggdeps = callPackage ../development/python-modules/eggdeps { };
+ eigenpy = toPythonModule (callPackage ../development/python-modules/eigenpy { });
+
einops = callPackage ../development/python-modules/einops { };
eiswarnung = callPackage ../development/python-modules/eiswarnung { };
@@ -3058,6 +3067,11 @@ self: super: with self; {
ewmh = callPackage ../development/python-modules/ewmh { };
+ example-robot-data = toPythonModule (pkgs.example-robot-data.override {
+ pythonSupport = true;
+ python3Packages = self;
+ });
+
exdown = callPackage ../development/python-modules/exdown { };
exceptiongroup = callPackage ../development/python-modules/exceptiongroup { };
@@ -6874,6 +6888,8 @@ self: super: with self; {
msgraph-core = callPackage ../development/python-modules/msgraph-core { };
+ multipart = callPackage ../development/python-modules/multipart { };
+
netmap = callPackage ../development/python-modules/netmap { };
onetimepad = callPackage ../development/python-modules/onetimepad { };
@@ -6954,6 +6970,11 @@ self: super: with self; {
pinboard = callPackage ../development/python-modules/pinboard { };
+ pinocchio = toPythonModule (pkgs.pinocchio.override {
+ pythonSupport = true;
+ python3Packages = self;
+ });
+
pint = callPackage ../development/python-modules/pint { };
pint-pandas = callPackage ../development/python-modules/pint-pandas { };
diff --git a/pkgs/development/misc/resholve/default.nix b/pkgs/development/misc/resholve/default.nix
index 34dd36a21243..df0573fd884f 100644
--- a/pkgs/development/misc/resholve/default.nix
+++ b/pkgs/development/misc/resholve/default.nix
@@ -1,19 +1,37 @@
{ lib
-, stdenv
+, pkgs
, pkgsBuildHost
, ...
}:
let
- pkgs = import ../../../.. {
- inherit (stdenv.hostPlatform) system;
- # Allow python27 with known security issues only for resholve,
- # see issue #201859 for the reasoning
- # In resholve case this should not be a security issue,
- # since it will only be used during build, not runtime
- config.permittedInsecurePackages = [ pkgsBuildHost.python27.name ];
+ python27' = (pkgsBuildHost.python27.overrideAttrs (old:
+ {
+ # Overriding `meta.knownVulnerabilities` here, see #201859 for why it exists
+ # In resholve case this should not be a security issue,
+ # since it will only be used during build, not runtime
+ meta = (old.meta or { }) // { knownVulnerabilities = [ ]; };
+ }
+ )).override {
+ self = python27';
+ pkgsBuildHost = pkgsBuildHost // { python27 = python27'; };
+ # strip down that python version as much as possible
+ openssl = null;
+ bzip2 = null;
+ readline = null;
+ ncurses = null;
+ gdbm = null;
+ sqlite = null;
+ libffi = null;
+ rebuildBytecode = false;
+ stripBytecode = true;
+ strip2to3 = true;
+ stripConfig = true;
+ stripIdlelib = true;
+ stripTests = true;
+ enableOptimizations = false;
};
- callPackage = lib.callPackageWith pkgs;
+ callPackage = lib.callPackageWith (pkgs // { python27 = python27'; });
source = callPackage ./source.nix { };
deps = callPackage ./deps.nix { };
in